# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

__all__ = ["TypeListParams"]


class TypeListParams(TypedDict, total=False):
    use_case_name: str
    """Use Case name"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .types import (
    TypesResource,
    AsyncTypesResource,
    TypesResourceWithRawResponse,
    AsyncTypesResourceWithRawResponse,
    TypesResourceWithStreamingResponse,
    AsyncTypesResourceWithStreamingResponse,
)
from .use_cases import (
    UseCasesResource,
    AsyncUseCasesResource,
    UseCasesResourceWithRawResponse,
    AsyncUseCasesResourceWithRawResponse,
    UseCasesResourceWithStreamingResponse,
    AsyncUseCasesResourceWithStreamingResponse,
)
from .properties import (
    PropertiesResource,
    AsyncPropertiesResource,
    PropertiesResourceWithRawResponse,
    AsyncPropertiesResourceWithRawResponse,
    PropertiesResourceWithStreamingResponse,
    AsyncPropertiesResourceWithStreamingResponse,
)

__all__ = [
    "TypesResource",
    "AsyncTypesResource",
    "TypesResourceWithRawResponse",
    "AsyncTypesResourceWithRawResponse",
    "TypesResourceWithStreamingResponse",
    "AsyncTypesResourceWithStreamingResponse",
    "PropertiesResource",
    "AsyncPropertiesResource",
    "PropertiesResourceWithRawResponse",
    "AsyncPropertiesResourceWithRawResponse",
    "PropertiesResourceWithStreamingResponse",
    "AsyncPropertiesResourceWithStreamingResponse",
    "UseCasesResource",
    "AsyncUseCasesResource",
    "UseCasesResourceWithRawResponse",
    "AsyncUseCasesResourceWithRawResponse",
    "UseCasesResourceWithStreamingResponse",
    "AsyncUseCasesResourceWithStreamingResponse",
]
